#[repr(C)]pub struct AVFilterLink {Show 28 fields
pub src: *mut AVFilterContext,
pub srcpad: *mut AVFilterPad,
pub dst: *mut AVFilterContext,
pub dstpad: *mut AVFilterPad,
pub type_: i32,
pub format: i32,
pub w: i32,
pub h: i32,
pub sample_aspect_ratio: AVRational,
pub colorspace: u32,
pub color_range: u32,
pub sample_rate: i32,
pub ch_layout: AVChannelLayout,
pub time_base: AVRational,
pub incfg: AVFilterFormatsConfig,
pub outcfg: AVFilterFormatsConfig,
pub graph: *mut AVFilterGraph,
pub current_pts: i64,
pub current_pts_us: i64,
pub frame_rate: AVRational,
pub min_samples: i32,
pub max_samples: i32,
pub frame_count_in: i64,
pub frame_count_out: i64,
pub sample_count_in: i64,
pub sample_count_out: i64,
pub frame_wanted_out: i32,
pub hw_frames_ctx: *mut AVBufferRef,
}Expand description
A link between two filters. This contains pointers to the source and destination filters between which this link exists, and the indexes of the pads involved. In addition, this link also contains the parameters which have been negotiated and agreed upon between the filter, such as image dimensions, format, etc.
Applications must not normally access the link structure directly. Use the buffersrc and buffersink API instead. In the future, access to the header may be reserved for filters implementation.
Fields
src: *mut AVFilterContext< source filter
srcpad: *mut AVFilterPad< output pad on the source filter
dst: *mut AVFilterContext< dest filter
dstpad: *mut AVFilterPad< input pad on the dest filter
type_: i32< filter media type
format: i32< agreed upon media format
w: i32< agreed upon image width
h: i32< agreed upon image height
sample_aspect_ratio: AVRational< agreed upon sample aspect ratio
colorspace: u32< agreed upon YUV color space
color_range: u32< agreed upon YUV color range
sample_rate: i32< samples per second
ch_layout: AVChannelLayout< channel layout of current buffer (see libavutil/channel_layout.h)
time_base: AVRationalDefine the time base used by the PTS of the frames/samples which will pass through this link. During the configuration stage, each filter is supposed to change only the output timebase, while the timebase of the input link is assumed to be an unchangeable property.
incfg: AVFilterFormatsConfigLists of supported formats / etc. supported by the input filter.
outcfg: AVFilterFormatsConfigLists of supported formats / etc. supported by the output filter.
graph: *mut AVFilterGraphGraph the filter belongs to.
current_pts: i64Current timestamp of the link, as defined by the most recent frame(s), in link time_base units.
current_pts_us: i64Current timestamp of the link, as defined by the most recent frame(s), in AV_TIME_BASE units.
frame_rate: AVRationalFrame rate of the stream on the link, or 1/0 if unknown or variable; if left to 0/0, will be automatically copied from the first input of the source filter if it exists.
Sources should set it to the best estimation of the real frame rate. If the source frame rate is unknown or variable, set this to 1/0. Filters should update it if necessary depending on their function. Sinks can use it to set a default output frame rate. It is similar to the r_frame_rate field in AVStream.
min_samples: i32Minimum number of samples to filter at once. If filter_frame() is called with fewer samples, it will accumulate them in fifo. This field and the related ones must not be changed after filtering has started. If 0, all related fields are ignored.
max_samples: i32Maximum number of samples to filter at once. If filter_frame() is called with more samples, it will split them.
frame_count_in: i64Number of past frames sent through the link.
frame_count_out: i64Number of past frames sent through the link.
sample_count_in: i64Number of past samples sent through the link.
sample_count_out: i64Number of past samples sent through the link.
frame_wanted_out: i32True if a frame is currently wanted on the output of this filter. Set when ff_request_frame() is called by the output, cleared when a frame is filtered.
hw_frames_ctx: *mut AVBufferRefFor hwaccel pixel formats, this should be a reference to the AVHWFramesContext describing the frames.